@@ -88,8 +88,10 @@ local function l_new(self, fnA)
 
    o.__forbiddenT        = {}  -- Table of forbidden modules
                                -- from LMOD_MODULERC files only
+   o.__forbiddenRxT      = {}  -- Table of forbidden modules that use Lua Regex strings
    o.__hiddenT           = {}  -- Table of hidden modules
                                -- from LMOD_MODULERC files only
+   o.__hiddenRxT         = {}  -- Table of hidden modules that use Lua Regex strings
    o.__mod2versionT      = false  -- Map from full module name to versions.
    o.__full2aliasesT     = false
    setmetatable(o,self)
@@ -266,8 +268,14 @@ function M.parseModA(self, modA, weight)
             self.__hiddenT[entry.mfile] = {kind="hidden"}
          elseif (entry.action == "hide") then
             self.__hiddenT[entry.name] = entry
+         elseif (entry.action == "hideRegex") then
+            entry.action = "hide"
+            self.__hiddenRxT[entry.name] = entry
          elseif (entry.action == "forbid") then
             self.__forbiddenT[entry.name] = entry
+         elseif (entry.action == "forbidRegex") then
+            entry.action = "forbid"
+            self.__forbiddenRxT[entry.name] = entry
          end
       until true
    end
@@ -485,6 +493,12 @@ function M.parseModA_for_moduleA(self, name, mpath, modA)
          l_store_mpathT(self, mpath, "hiddenT", entry.name, entry);
       elseif (entry.action == "forbid") then
          l_store_mpathT(self, mpath, "forbiddenT", entry.name, entry);
+      elseif (entry.action == "hideRegex") then
+         entry.action = "hide"
+         l_store_mpathT(self, mpath, "hiddenRxT", entry.name, entry);
+      elseif (entry.action == "forbidRegex") then
+         entry.action = "forbid"
+         l_store_mpathT(self, mpath, "forbiddenRxT", entry.name, entry);
       end
    end
    dbg.fini("MRC:parseModA_for_moduleA")
@@ -508,50 +522,108 @@ function M.extract(self)
    return t, self.__mpathT
 end
 function M.export(self)
-   local t, mrcMpathT = self:extract()
-   local a = {}
-   --a[1] = serializeTbl{indent = true, name = "mrcT",      value = t         }
-   --a[2] = serializeTbl{indent = true, name = "mrcMpathT", value = mrcMpathT }
-   --return concatTbl(a,"\n")
+   local mrcMpathT = self:mrcMpathT()
    return serializeTbl{indent = true, name = "mrcMpathT", value = mrcMpathT }
 end
 
-local function l_find_resultT(self, tbl_kind, replaceT, mpath, wantedA)
-   --dbg.start{"MRC:l_find_resultT( tbl_kind, replaceT, mpath, wantedA)"}
+local function l_find_resultT(self, tbl_kind, tbl_kindRx, replaceT, mpath, wantedA)
+   dbg.start{"MRC:l_find_resultT( tbl_kind: ",tbl_kind,", tbl_kindRx, replaceT, mpath, wantedA)"}
    local resultT = false
-   local Tkind   = "__" .. tbl_kind
-   local tt      = {}
-   local ttt     = self[Tkind] or {}
+   local mpathA  = {mpath}
+
+   ----------------------------------------------------------------------
+   -- Check non-regex names first
+   ----------------------------------------------------------------------
+
+   local modTreeMRCT = {}
+   local lmodMRCT    = self["__" .. tbl_kind] or {}
 
    if (self.__mpathT[mpath] and self.__mpathT[mpath][tbl_kind]) then
-      tt  = self.__mpathT[mpath][tbl_kind]
+      modTreeMRCT    = self.__mpathT[mpath][tbl_kind]
    end
-   --dbg.print{"mpath: ",mpath,"\n"}
-   --dbg.printT("wantedA",wantedA)
-   --dbg.printT("ttt", ttt)
-   --dbg.printT("tt", tt)
-   --dbg.printT("mpathT", self.__mpathT)
 
-   local mpathA = {mpath}
+   dbg.print{"mpath: ",      mpath,"\n"}
+   dbg.printT("wantedA",     wantedA)
+   dbg.printT("lmodMRCT[".."__" .. tbl_kind .. "]", lmodMRCT)
+   dbg.printT("modTreeMRCT", modTreeMRCT)
+   dbg.printT("mpathT",      self.__mpathT)
+
    for i = 1,#wantedA do
       local wanted = wantedA[i]
       local key    = self:resolve(mpathA, wanted)
-      local ans    = ttt[key] or tt[key]
+      local ans    = lmodMRCT[key] or modTreeMRCT[key]
       if (ans) then
          if (type(ans) == "table") then
             resultT = ans
          else
             resultT = replaceT
          end
-         --dbg.printT("resultT",resultT)
-         --dbg.fini("MRC:l_find_resultT")
+         dbg.printT("resultT",resultT)
+         dbg.fini("MRC:l_find_resultT via non-regex match")
          return resultT
       end
    end
-   --dbg.fini("MRC:l_find_resultT (false)")
+
+   ----------------------------------------------------------------------
+   -- Check regex names 
+   ----------------------------------------------------------------------
+   
+
+   lmodMRCT = self["__" .. tbl_kindRx] or {}
+   dbg.printT("lmodMRCT[".."__" .. tbl_kindRx .. "]",lmodMRCT)
+   if (next(lmodMRCT) == nil) then
+      dbg.print{"lmodMRCT has zero keys\n"}
+   end
+   for k, ans in pairs(lmodMRCT) do
+      dbg.print{"lmodMRCT: k: ",k,"\n"}
+      for i = 1,#wantedA do
+         local wanted = wantedA[i]
+         local key    = self:resolve(mpathA, wanted)
+         dbg.print{"lmodMRCT: key: ",key,", wanted: ",wanted,"\n"}
+         if (key:find(k)) then
+            if (type(ans) == "table") then
+               resultT = ans
+            else
+               resultT = replaceT
+            end
+            dbg.printT("resultT",resultT)
+            dbg.fini("MRC:l_find_resultT via regex match from RTMlmodMRCT")
+            
+            return resultT
+         end
+      end
+   end
+   
+   modTreeMRCT = {}
+   if (self.__mpathT[mpath] and self.__mpathT[mpath][tbl_kindRx]) then
+      modTreeMRCT    = self.__mpathT[mpath][tbl_kindRx]
+   end
+   dbg.printT("modTreeMRCT",modTreeMRCT)
+   for k, ans in pairs(modTreeMRCT) do
+      dbg.print{"modTreeMRCT: k: ",k,"\n"}
+      for i = 1,#wantedA do
+         local wanted = wantedA[i]
+         local key    = self:resolve(mpathA, wanted)
+         dbg.print{"modTreeMRCT: key: ",key,", wanted: ",wanted,"\n"}
+
+         if (key:find(k)) then
+            if (type(ans) == "table") then
+               resultT = ans
+            else
+               resultT = replaceT
+            end
+            dbg.printT("resultT",resultT)
+            dbg.fini("MRC:l_find_resultT via regex match from modTreeMRCT")
+            return resultT
+         end
+      end
+   end
+   dbg.fini("MRC:l_find_resultT (false)")
    return resultT
 end
 
+
+
 local function l_findHiddenState(self, modT)
    --dbg.start{"l_findHiddenState(self, modT)"}
    local fn      = modT.fn
@@ -564,7 +636,7 @@ local function l_findHiddenState(self, modT)
       wantedA[#wantedA + 1] = n
    end
 
-   local resultT = l_find_resultT(self, "hiddenT", {kind = "hidden"}, modT.mpath, wantedA)
+   local resultT = l_find_resultT(self, "hiddenT", "hiddenRxT", {kind = "hidden"}, modT.mpath, wantedA)
 
    -- Apply isVisibleHook, convert false isVisible flag to resultT.
    if (hook.exists("isVisibleHook")) then
@@ -590,7 +662,7 @@ local function l_findForbiddenState(self, mpath, sn, fullName, fn)
       _, _, n = n:find("(.*)/.*")
       wantedA[#wantedA + 1] = n
    end
-   local resultT = l_find_resultT(self, "forbiddenT", {}, mpath, wantedA)
+   local resultT = l_find_resultT(self, "forbiddenT", "forbiddenRxT", {}, mpath, wantedA)
 
    dbg.fini("l_findForbiddenState")
    return resultT or {}
@@ -782,7 +854,7 @@ function M.isVisible(self, modT)
 end
 
 function M.isForbidden(self, modT)
-   --dbg.start{"MRC:isForbidden(modT}"}
+   dbg.start{"MRC:isForbidden(modT}"}
    local frameStk     = require("FrameStk"):singleton()
    local mname        = frameStk:mname()
    local mt           = frameStk:mt()
@@ -796,10 +868,11 @@ function M.isForbidden(self, modT)
    local resultT      = l_findForbiddenState(self, mpath, sn, fullName, fn)
 
    --dbg.print{"fullName: ",fullName,"\n"}
-   --dbg.printT("resultT",resultT)
+   dbg.printT("resultT",resultT)
 
+   --if (resultT.action ~= "forbid" and resultT.action ~= "forbidRegex") then
    if (resultT.action ~= "forbid") then
-      --dbg.fini("MRC:isForbidden")
+      dbg.fini("MRC:isForbidden")
       return nil
    end
 
@@ -815,7 +888,8 @@ function M.isForbidden(self, modT)
    local my_resultT  = {forbiddenState = modT.forbiddenState, message = modT.message,
                         nearlymessage = modT.nearlymessage, after = resultT.after}
 
-   --dbg.fini("MRC:isForbidden")
+   dbg.printT("my_resultT",my_resultT)
+   dbg.fini("MRC:isForbidden")
    return my_resultT
 end
 
